@@ -104,21 +104,15 @@ if (len < 34) {
 elementSymbol = this.line.substring (31).trim ();
 } else {
 elementSymbol = this.line.substring (31, 34).trim ();
-if (len >= 39) {
+if (elementSymbol.equals ("H1")) {
+elementSymbol = "H";
+isotope = 1;
+}if (len >= 39) {
 var code = this.parseIntRange (this.line, 36, 39);
 if (code >= 1 && code <= 7) charge = 4 - code;
 code = this.parseIntRange (this.line, 34, 36);
 if (code != 0 && code >= -3 && code <= 4) {
-isotope = J.api.JmolAdapter.getNaturalIsotope (J.api.JmolAdapter.getElementNumber (elementSymbol));
-switch (isotope) {
-case 0:
-break;
-case 1:
-isotope = -code;
-break;
-default:
-isotope += code;
-}
+isotope = J.api.JmolAdapter.getNaturalIsotope (J.api.JmolAdapter.getElementNumber (elementSymbol)) + code;
 }if (iAtom == -2147483648 && this.haveAtomSerials) iAtom = i + 1;
 }}this.addMolAtom (iAtom, isotope, elementSymbol, charge, x, y, z);
 }
@@ -179,7 +173,7 @@ var ipt = this.parseIntAt (this.line, pt);
 var atom = this.asc.atoms[ipt + i0 - 1];
 var iso = this.parseIntAt (this.line, pt + 4);
 pt += 8;
-atom.elementSymbol = "" + iso + atom.elementSymbol;
+atom.elementSymbol = "" + iso + JU.PT.replaceAllCharacters (atom.elementSymbol, "0123456789", "");
 }
 } catch (e) {
 }
@@ -239,11 +233,14 @@ function (iAtom, isotope, elementSymbol, charge, x, y, z) {
 switch (isotope) {
 case 0:
 break;
-case -1:
-elementSymbol = "D";
+case 1:
+elementSymbol = "1H";
 break;
-case -2:
-elementSymbol = "T";
+case 2:
+elementSymbol = "2H";
+break;
+case 3:
+elementSymbol = "3H";
 break;
 default:
 elementSymbol = isotope + elementSymbol;
